"""
Flask commands
"""
import putio_automator.commands.account
import putio_automator.commands.config
import putio_automator.commands.db
import putio_automator.commands.files
import putio_automator.commands.torrents
import putio_automator.commands.transfers
